# `anilibria`

![version](https://img.shields.io/badge/Project_version-0.1.8-blue)
![licence](https://img.shields.io/badge/License-MIT-green)
[![pypi](https://img.shields.io/badge/anilibria_on_PyPi-blue)](https://pypi.org/project/anilibria)
![python](https://img.shields.io/badge/Python-3.9%2B-blue)

> [!CAUTION]  
> **It is not an official wrapper.** [Official AniLibria's REST API](https://github.com/anilibria/docs/blob/master/api_v3.md)

A Python API wrapper for AniLibria, designed to interact with AniLibria's database and retrieve anime-related information.

*P.S. You can download animes with this library.*

# Installing 🛠️
**Python 3.9 or above is required.**

### pip
To install from PyPI with pip:
```
$ pip install anilibria
```

### poetry
You can add `anilibria` as a dependency with the following command
```
$ poetry add anilibria
```

## Documentation 📃
You can find docs [here](https://github.com/anekobtw/anilibria/blob/main/docs.md).

## Contributing 🤝
We welcome contributions! Please read our [Code of Conduct](https://github.com/anekobtw/anilibria/blob/main/CODE_OF_CONDUCT.md)

## License 📄
`anilibria` is [MIT](https://github.com/anekobtw/anilibria/blob/main/LICENSE) licenced.

For additional support, [open an issue](https://github.com/anekobtw/youtube-dl-bot/issues).

> // Maintained with ❤️ by [@anekobtw](https://github.com/anekobtw)
